'use client'

import { useRef, useEffect, useLayoutEffect } from 'react';

import * as style from './Marquee.css';

export default function Marquee({ children }: { children: React.ReactNode }) {
	const target_ref        = useRef<HTMLDivElement       | null>(null);
	const scroll_ref        = useRef<HTMLDivElement       | null>(null);
	const sneaky_ref        = useRef<HTMLParagraphElement | null>(null);
	const not_so_sneaky_ref = useRef<HTMLParagraphElement | null>(null);

	function expand_content() {
		function strip_px(px: string) {
			return Number(px.substring(0, px.length - 2));
		}
		const text         = `${children}`;
		let   content      = text;
		const sneaky_width = strip_px(window.getComputedStyle(sneaky_ref.current!).getPropertyValue("width"));
		let   target_width = strip_px(window.getComputedStyle(target_ref.current!).getPropertyValue("width"));
		while (target_width > 0) {
			content += text;
			target_width -= sneaky_width;
		}
		scroll_ref.current!.style.width = `${sneaky_width}px`;
		not_so_sneaky_ref.current!.textContent = content;
	}

	useLayoutEffect(expand_content);

	useEffect(() => {
		window.addEventListener("resize", expand_content);

		return () => {
			window.removeEventListener("resize", expand_content);
		}
	});

	return (
		<div ref={target_ref} className={style.marquee_container}>
			<p ref={sneaky_ref} className={style.marquee_sneaky}>{children}</p>
			<div ref={scroll_ref}>
				<p ref={not_so_sneaky_ref} className={style.marquee_content}></p>
			</div>
		</div>
	);
}
